<template>
    <v-card elevation="3">
        <v-card-title class="subtitle-1">
            Add a member
        </v-card-title>
        <v-divider/>
        <v-card-text>
            <v-form class="mt-3">
                <v-row>

                    <v-col cols="6">
                        <v-text-field label="Name" v-model="form.name" :loading="loading"
                                      :error-messages="error.name"
                                      outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="6">
                        <v-text-field label="Email" v-model="form.email" :loading="loading"
                                      :error-messages="error.email" outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="6">
                        <v-text-field label="Password" v-model="form.password" type="password" :loading="loading"
                                      :error-messages="error.password" outlined dense></v-text-field>
                    </v-col>

                    <v-col>
                        <v-text-field label="Photo" v-model="form.photo.label" outline dense
                                      placeholder="Paste URL or click Browse">
                            <v-btn @click="selectPhoto" text slot="append" dense v-if="!form.photo.id">
                                Browse <v-icon right color="primary">mdi-folder-open</v-icon>
                            </v-btn>
                            <v-btn @click="form.photo = {}" text slot="append" dense v-else>
                                Remove <v-icon right color="error">mdi-delete</v-icon>
                            </v-btn>
                        </v-text-field>
                    </v-col>
                </v-row>
            </v-form>
            <v-divider/>
        </v-card-text>
        <v-card-actions>
            <v-row>
                <v-spacer/>
                <v-col align="end">
                    <v-btn class="" text small :loading="loading" @click="storeUser" color="primary">
                        Save
                        <v-icon right>mdi-content-save-outline</v-icon>
                    </v-btn>
                </v-col>
            </v-row>
        </v-card-actions>
    </v-card>
</template>

<script>
import Settings from "../../../Components/Layouts/Settings.vue";
import Setting from "../Setting.vue";
import User from "./PaymentMethod.vue";

export default {
    name: "UserCreate",
    layout: [Settings, Setting, User],
    props: {},
    data() {
        return {
            loading: false,
            error: {
                name: [],
                email: [],
                password: [],
                photo: {}
            },
            form: {
                name: '',
                email: '',
                password: '',
                photo: {}
            },
            eventSubscription: null
        }
    },
    methods: {
        clearError() {
            for (let i in this.error) {
                this.error[i] = []
            }
        },
        storeUser() {
            this.$inertia.post(this.$route('user.store'), this.form, {
                onBefore: () => {
                    this.loading = true
                },
                onSuccess: (page) => {
                    this.showSnack(["Successfully saved new member!"])
                },
                onError: (errors) => {
                    if (errors && Object.values(errors).length) {
                        this.showSnack([Object.values(errors)[0], "error"])
                    }
                },
                onFinish: visit => {
                    this.loading = false
                },
            });
        },
        selectPhoto() {
            let eventName = 'landlord-profilexxx'
            this.eventSubscription = this.$store.subscribe((mutation, state) => {
                if (mutation.type === "Media/SET_EVENT_NAME" && mutation.payload === eventName) {
                    if (state.Media.media.length) {
                        this.form.photo = state.Media.media[0]
                        this.eventSubscription()
                    }
                }
            });
            this.showMediaDialog({event: eventName, type: 'image'})
        }
    },
    mounted() {
    }
}
</script>

<style>

</style>
